summaryrefslogtreecommitdiff
path: root/ui
diff options
context:
space:
mode:
authorPeter Maydell <peter.maydell@linaro.org>2017-03-28 12:34:23 +0100
committerPeter Maydell <peter.maydell@linaro.org>2017-03-28 12:34:23 +0100
commit0491c221547a38b58e41fade9953cd1cf015288b (patch)
treecf322d06789d866c1ffd9555df3194dc3b53fe4d /ui
parent142b9ca51d7260d20f6e87bd7f2020ac0a7d95d9 (diff)
parent5b12c163c830081cbb78e2de3b42c5fe1b73e74e (diff)
downloadqemu-0491c221547a38b58e41fade9953cd1cf015288b.tar.gz
Merge remote-tracking branch 'remotes/stsquad/tags/pull-mttcg-fixups-for-rc2-280317-1' into staging
MTTCG regression fixes for rc2 # gpg: Signature made Tue 28 Mar 2017 10:54:38 BST # gpg: using RSA key 0xFBD0DB095A9E2A44 # gpg: Good signature from "Alex Bennée (Master Work Key) <alex.bennee@linaro.org>" # Primary key fingerprint: 6685 AE99 E751 67BC AFC8 DF35 FBD0 DB09 5A9E 2A44 * remotes/stsquad/tags/pull-mttcg-fixups-for-rc2-280317-1: replay/replay.c: bump REPLAY_VERSION tcg: Add a new line after incompatibility warning ui/console: use exclusive mechanism directly ui/console: ensure do_safe_dpy_refresh holds BQL bsd-user: align use of mmap_lock to that of linux-user user-exec: handle synchronous signals from QEMU gracefully Signed-off-by: Peter Maydell <peter.maydell@linaro.org>
Diffstat (limited to 'ui')
-rw-r--r--ui/console.c18
1 files changed, 11 insertions, 7 deletions
diff --git a/ui/console.c b/ui/console.c
index 937c950840..419b098c11 100644
--- a/ui/console.c
+++ b/ui/console.c
@@ -1576,17 +1576,22 @@ bool dpy_gfx_check_format(QemuConsole *con,
}
/*
* Safe DPY refresh for TCG guests. This runs when the TCG vCPUs are
* quiescent so we can avoid races between dirty page tracking for
* direct frame-buffer access by the guest.
*
* This is a temporary stopgap until we've fixed the dirty tracking
* races in display adapters.
*/
-static void do_safe_dpy_refresh(CPUState *cpu, run_on_cpu_data opaque)
+static void do_safe_dpy_refresh(DisplayChangeListener *dcl)
{
- DisplayChangeListener *dcl = opaque.host_ptr;
+ qemu_mutex_unlock_iothread();
+ start_exclusive();
+ qemu_mutex_lock_iothread();
dcl->ops->dpy_refresh(dcl);
+ qemu_mutex_unlock_iothread();
+ end_exclusive();
+ qemu_mutex_lock_iothread();
}
static void dpy_refresh(DisplayState *s)
@@ -1596,8 +1601,7 @@ static void dpy_refresh(DisplayState *s)
QLIST_FOREACH(dcl, &s->listeners, next) {
if (dcl->ops->dpy_refresh) {
if (tcg_enabled()) {
- async_safe_run_on_cpu(first_cpu, do_safe_dpy_refresh,
- RUN_ON_CPU_HOST_PTR(dcl));
+ do_safe_dpy_refresh(dcl);
} else {
dcl->ops->dpy_refresh(dcl);
}
@@ -1576,17 +1576,22 @@ bool dpy_gfx_check_format(QemuConsole *con,
}
/*
- * Safe DPY refresh for TCG guests. This runs when the TCG vCPUs are
- * quiescent so we can avoid races between dirty page tracking for
- * direct frame-buffer access by the guest.
+ * Safe DPY refresh for TCG guests. We use the exclusive mechanism to
+ * ensure the TCG vCPUs are quiescent so we can avoid races between
+ * dirty page tracking for direct frame-buffer access by the guest.
*
* This is a temporary stopgap until we've fixed the dirty tracking